package org.codehaus.mojo.jsimport;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.apache.maven.artifact.repository.ArtifactRepository;
import org.apache.maven.project.MavenProject;

/**
 * Collect a list of local repositories and provide a means of determining which repository a given file belongs to.
 * 
 * @author Christopher Hunt
 */
public class LocalRepositoryCollector
{
    private final List<String> localRepositoryPaths = new ArrayList<String>();

    /**
     * Constructor.
     * 
     * @param project The Maven project to be processed.
     * @param localRepository The local repository being used by Maven.
     * @param wwwZipFolderBase the location of expanded www zip files or null if these are not to be considered.
     */
    public LocalRepositoryCollector( MavenProject project, ArtifactRepository localRepository, File wwwZipFolderBase )
    {
        // The local repo will always be in this list and it is optimal to assume that it will be hit tested the most
        // outside of here.
        localRepositoryPaths.add( localRepository.getBasedir() );

        // Determine the root project

        String projectArtifactId = project.getArtifactId();

        MavenProject parentProject = project.getParent();
        while ( parentProject != null )
        {
            List<?> modules = parentProject.getModules();
            if ( modules.contains( projectArtifactId ) )
            {
                projectArtifactId = parentProject.getArtifactId();
                String parentProjectPath = parentProject.getBasedir().getAbsolutePath();
                localRepositoryPaths.add( parentProjectPath );
            }
            else
            {
                break;
            }

            parentProject = parentProject.getParent();
        }

        // -www.zip folders can be considered as local repos if we've had the base passed in.
        if ( wwwZipFolderBase != null )
        {
            File[] wwwZipFolders = wwwZipFolderBase.listFiles();
            if ( wwwZipFolders != null )
            {
                for ( File wwwZipFolder : wwwZipFolders )
                {
                    localRepositoryPaths.add( wwwZipFolder.getAbsolutePath() );
                }
            }
        }
    }

    /**
     * Find a file within our collection of local repositories.
     * 
     * @param filePath the file to be found in a local repo.
     * @return the local repo found that houses the file.
     */
    public String findLocalRepository( String filePath )
    {
        String localRepositoryPathFound = null;
        for ( String localRepositoryPath : localRepositoryPaths )
        {
            if ( filePath.startsWith( localRepositoryPath ) )
            {
                localRepositoryPathFound = localRepositoryPath;
                break;
            }
        }
        return localRepositoryPathFound;
    }

    /**
     * @param path a path to add to the list of paths to be considered as local repos.
     */
    public void addLocalRepositoryPath( String path )
    {
        localRepositoryPaths.add( path );
    }
}
